<?php declare(strict_types=1);
/**
 * JTL Plugin
 * Copyright (C) 2011 - 2020 Andreas Petermann
 *
 * PHP version 7.2+
 *
 * @copyright css-umsetzung
 * @author Andreas Petermann <info@css-umsetzung.de>
 * @package css_zubehoer
 * @license GNU
 * @version 2.00
 *
 */

namespace Plugin\css_zubehoer;

use JTL\Alert\Alert;
use JTL\Catalog\Category\Kategorie;
use JTL\Catalog\Product\Artikel;
use JTL\Events\Dispatcher;
use JTL\Events\Event;
use JTL\Helpers\Form;
use JTL\Helpers\Request;
use JTL\Link\LinkInterface;
use JTL\Plugin\Bootstrapper;
use JTL\Shop;
use JTL\Smarty\JTLSmarty;
use Plugin\css_zubehoer\src\cssPlugin;

class Bootstrap extends Bootstrapper
{
    /**
     * @var TestHelper
     */
    private $cssPlugin;

    /**
     * @inheritdoc
     */
    public function boot(Dispatcher $dispatcher)
    {
        parent::boot($dispatcher);
            $plugin = $this->getPlugin();
        if (Shop::isFrontend() === true || (isset($_REQUEST['kPlugin']) &&  $plugin->getID() == (int) $_REQUEST['kPlugin'])) {
            $this->cssPlugin = src\cssPlugin\cssPlugin::getInstance(
                $plugin,
                $this->getDB(),
                $this->getCache()
            );
        }
        if (Shop::isFrontend() === true) {
            $cfg = $this->cssPlugin->getConfig();
            if($cfg->pluginActive=='N') return;
            $dispatcher->listen('shop.hook.' . \HOOK_IO_HANDLE_REQUEST, function (array $args) use ($plugin) {
                $this->cssPlugin->hookIoHandleRequest($args);
            });
            $dispatcher->listen('shop.hook.' . \HOOK_ARTIKEL_INC_XSELLING, function (array $args) use ($plugin) {
                $this->cssPlugin->hookArtikelIncXselling($args);
            });
            $dispatcher->listen('shop.hook.' . \HOOK_ARTIKEL_PAGE, function (array $args) use ($plugin) {
                $this->cssPlugin->hookArtikelPage($args);
            });
            $dispatcher->listen('shop.hook.' . \HOOK_ARTIKEL_INC_XSELLING, function (array $args) use ($plugin) {
                $this->cssPlugin->hookArtikelIncXselling($args);
            });
            $dispatcher->listen('shop.hook.' . \HOOK_SMARTY_OUTPUTFILTER, function () use ($plugin) {
                $this->cssPlugin->hookSmartyOutputfilter();
            });
        }
    }


    /**
     * @inheritdoc
     */
    public function installed()
    {
        $plugin  = $this->getPlugin();
        $this->getCache()->flushTags('cache_'.$plugin->getPluginID());
        parent::installed();
    }

    /**
     * @inheritdoc
     */
    public function updated($oldVersion, $newVersion)
    {
        $plugin  = $this->getPlugin();
        $this->getCache()->flushTags('cache_'.$plugin->getPluginID());
        \error_log('updated from ' . $oldVersion . ' to ' . $newVersion);
    }

    /**
     * @inheritdoc
     */
    public function uninstalled(bool $deleteData = true)
    {
        $plugin  = $this->getPlugin();
        if($deleteData === true) {
            $this->getDB()->query('DROP TABLE IF EXISTS `css_zubehoerConfig`', 3);
        }
        $this->getCache()->flushTags('cache_'.$plugin->getPluginID());
        parent::uninstalled($deleteData);
    }

    /**
     * @inheritdoc
     */

}
